=======
seshypy
=======
----------------------------------------------------------------
seshypy makes API Gateway requests and API Gateway clients easy.
----------------------------------------------------------------

Features
--------

- Make API Gateway signed requests.
- Helper methods for delete, get, post, and put.
- Permanent STS hops creds creds resolver.
- Session sharing.
- Method caching with TTL.

  - given secrets
  - resolved from shared credential) (using transparent STS or secrets)
  - given role (using shared credentials)
  - given secrets and role

- Multiple authentication methods.

Documentation
-------------

Documentation can be found at `<https://seshypy.readthedocs.io/>`_.
